@@ -18,3 +18,7 @@
 ( cd opt/kde/share/doc/HTML/en/quanta ; ln -sf /opt/kde/share/doc/HTML/en/common common )
 ( cd opt/kde/share/doc/HTML/en/kommander ; rm -rf common )
 ( cd opt/kde/share/doc/HTML/en/kommander ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/xsldbg ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/xsldbg ; ln -sf /opt/kde/share/doc/HTML/en/common common )
+( cd opt/kde/share/doc/HTML/en/kfilereplace ; rm -rf common )
+( cd opt/kde/share/doc/HTML/en/kfilereplace ; ln -sf /opt/kde/share/doc/HTML/en/common common )
